Documentation
¶
Overview ¶
Package sseq is a lightweight tracing SDK for Go.
Core flow: Setup → Trace/Start → attributes/events → Shutdown. Spans are exported to Seq or Axiom over HTTP, or written to a file for Vector.
Index ¶
- func Error(ctx context.Context, err error)
- func Event(ctx context.Context, name string, keyValues ...any)
- func HTTP(next http.Handler) http.Handler
- func IDs(ctx context.Context) (traceID, spanID string, ok bool)
- func Resume(ctx context.Context, traceID, parentSpanID string) context.Context
- func Set(ctx context.Context, key string, value any)
- func SetupAxiom(token, dataset, application string) error
- func SetupAxiomFile(filename, application string) error
- func SetupSeq(endpoint, apiKey, application string) error
- func SetupSeqFile(filename, application string) error
- func Shutdown()
- func Start(ctx context.Context, name, kind string) (context.Context, func())
- func Trace(ctx context.Context, name, kind string, fn func(context.Context) error) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetupAxiom ¶ added in v0.5.0
SetupAxiom sends spans to Axiom over HTTP.
func SetupAxiomFile ¶ added in v0.5.0
SetupAxiomFile writes Axiom NDJSON spans to a local file for Vector → Axiom.
func SetupSeqFile ¶ added in v0.5.0
SetupSeqFile writes CLEF spans to a local file for Vector → Seq.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.