Documentation
¶
Overview ¶
Package ss holds shared internal types for sseq.
Index ¶
Constants ¶
const ( DefaultBatchSize = 20 DefaultFlushInterval = time.Second DefaultHTTPTimeout = 10 * time.Second )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BatchConfig ¶
BatchConfig controls asynchronous flush behavior.
type Sender ¶
type Sender struct {
// contains filtered or unexported fields
}
Sender batches encoded spans and flushes them through a Writer.
func NewSender ¶
func NewSender(config BatchConfig, encoder Encoder, writer Writer) *Sender
NewSender creates an asynchronous span sender.
type SpanEvent ¶
type SpanEvent struct {
Name string
Application string
TraceID string
SpanID string
ParentID string
SpanKind string
StartTime time.Time
EndTime time.Time
HasError bool
StatusMessage string
HTTPStatusCode int
Events []TimedEvent
Attributes map[string]any
}
SpanEvent is a completed span ready for encoding and delivery.
type TimedEvent ¶
TimedEvent is a point-in-time annotation attached to a span.
Click to show internal directories.
Click to hide internal directories.